@@ -7,7 +7,7 @@ use Carp qw(croak);
 use Logging::Simple;
 use LWP::Simple qw(head);
 
-our $VERSION = '2.17';
+our $VERSION = '2.18';
 
 my $log;
 
@@ -115,9 +115,6 @@ sub revision {
         $csum = `"$git" rev-parse HEAD`;
     }
     else {
-        # void capture, as there's unneeded stuff going to STDERR
-        # on the ls-remote call
-
         if (! defined $repo){
             $log->_0(
                 "Git::revision() requires a repo sent in while in remote " .
@@ -127,7 +124,10 @@ sub revision {
                   "remote mode.";
         }
 
-        $log->_6("remote: 'ls-remote' sent");
+        $log->_6("remote: 'ls-remote $repo' sent");
+
+        # void capture, as there's unneeded stuff going to STDERR
+        # on the ls-remote call
 
         capture_stderr {
             my $sums = `"$git" ls-remote $repo`;
